<?php

namespace Litecms\Career\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\Career\Interfaces\CareerRepositoryInterface;

class CareerPublicController extends BaseController
{
    // use CareerWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\Career\Interfaces\CareerRepositoryInterface $career
     *
     * @return type
     */
    public function __construct(CareerRepositoryInterface $career)
    {
        $this->repository = $career;
        parent::__construct();
    }

    /**
     * Show career's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $careers = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$career::$career.names'))
            ->view('$career::public.career.index')
            ->data(compact('$careers'))
            ->output();
    }

    /**
     * Show career's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $careers = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$career::$career.names'))
            ->view('$career::public.career.index')
            ->data(compact('$careers'))
            ->output();
    }

    /**
     * Show career.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $career = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$career->name . trans('$career::$career.name'))
            ->view('$career::public.career.show')
            ->data(compact('$career'))
            ->output();
    }

}
