<?php

namespace Litecms\Career\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Career\Models\Career;

class CareerPolicy
{

    /**
     * Determine if the given user can view the career.
     *
     * @param UserPolicy $user
     * @param Career $career
     *
     * @return bool
     */
    public function view(UserPolicy $user, Career $career)
    {
        if ($user->canDo('career.career.view') && $user->isAdmin()) {
            return true;
        }

        return $career->user_id == user_id() && $career->user_type == user_type();
    }

    /**
     * Determine if the given user can create a career.
     *
     * @param UserPolicy $user
     * @param Career $career
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('career.career.create');
    }

    /**
     * Determine if the given user can update the given career.
     *
     * @param UserPolicy $user
     * @param Career $career
     *
     * @return bool
     */
    public function update(UserPolicy $user, Career $career)
    {
        if ($user->canDo('career.career.edit') && $user->isAdmin()) {
            return true;
        }

        return $career->user_id == user_id() && $career->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given career.
     *
     * @param UserPolicy $user
     * @param Career $career
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Career $career)
    {
        return $career->user_id == user_id() && $career->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given career.
     *
     * @param UserPolicy $user
     * @param Career $career
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Career $career)
    {
        if ($user->canDo('career.career.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given career.
     *
     * @param UserPolicy $user
     * @param Career $career
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Career $career)
    {
        if ($user->canDo('career.career.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
